# newpipelist

A utility to convert playlists in a [NewPipe](https://newpipe.net/) database export to M3U files.

- Install: `pip install newpipelist`
- [Source Code (Git)](https://codeberg.org/gwymor/newpipelist.git): `git clone https://codeberg.org/gwymor/newpipelist.git`
- Requirements: sqlite3

Send patches to gwymor AT tilde DOT club.

## License

MIT
